==> ejc-proequipmentcorp-impl-3.0.0-20221021.122354-51-sources.jar: com/ejianc/business/proequipmentcorprent/rent/bean/RentRentalQuantitiesEntity.java <==
package com.ejianc.business.proequipmentcorprent.rent.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 租金计算工程量租明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_rent_rental_quantities")
public class RentRentalQuantitiesEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="quuipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="quantities_factory_code")
    private String quantitiesFactoryCode; // 设备出厂编号
    @TableField(value="category_id")
    private Long categoryId; // 设备类别id
    @TableField(value="category_name")
    private String categoryName; // 设备类别名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_name")
    private String unitName; // 单位
    @TableField(value="quantities_num")
    private Integer quantitiesNum; // 工程数量
    @TableField(value="quantities_price")
    private BigDecimal quantitiesPrice; // 工程量单价
    @TableField(value="rent_num")
    private Integer rentNum; // 租赁数量
    @TableField(value="tax")
    private BigDecimal tax; // 税率
    @TableField(value="plan_into_date")
    private Date planIntoDate; // 计划进程日期
    @TableField(value="plan_out_date")
    private Date planOutDate; // 计划出场日期
    @TableField(value="production_manufactor")
    private String productionManufactor; // 生产厂家
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="rental_id")
    private Long rentalId; // 主表id
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编号
    @TableField(value="equipment_id")
    private Long equipmentId; // 设备id
    @TableField(value="not_tax_quantities_price")
    private BigDecimal notTaxQuantitiesPrice; // 
    @TableField(value="not_tax_quantities_mny")
    private BigDecimal notTaxQuantitiesMny; // 无税工程量金额
    @TableField(value="change_bid")
    private Long changeBid; // 变更子表id
    @TableField(value="billing_unit_id")
    private Long billingUnitId; // 计费单位
    @TableField(value="billing_unit_name")
    private String billingUnitName; // 计费单位名称
    @TableField(value="source_id")
    private Long sourceId; // 来源id
    @TableField(value="rent_quantities_mny")
    private BigDecimal rentQuantitiesMny; // 租赁金额(无税)
    @TableField(value="rent_quantities_tax_mny")
    private BigDecimal rentQuantitiesTaxMny; // 租赁金额
    @TableField(value="rent_quantities_tax")
    private BigDecimal rentQuantitiesTax; // 租赁税额
    @TableField(value="charging_start_date")
    private Date chargingStartDate; // 计费开始日期
    @TableField(value="charging_end_date")
    private Date chargingEndDate; // 计费结束日期
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源明细主键ID
    @TableField(value="source_name")
    private String sourceName; // 来源类型名称(记录—100231)
    @TableField(value="source_type")
    private Integer sourceType; // 来源类型
    @TableField(value="source_code")
    private String sourceCode; // 来源编码

    @TableField(value="wbs_id")
    private Long wbsId; // 核算对象主键
    @TableField(value="wbs_code")
    private String wbsCode; // 核算对象编码
    @TableField(value="wbs_name")
    private String wbsName; // 核算对象名称
    @TableField(value="subject_id")
    private Long subjectId; // 成本科目主键
    @TableField(value="subject_code")
    private String subjectCode; // 成本科目编码
    @TableField(value="subject_name")
    private String subjectName; // 成本科目名称

    @TableField(value="equipment_state")
    private Integer equipmentState;

    public Integer getEquipmentState() {
        return equipmentState;
    }

    public void setEquipmentState(Integer equipmentState) {
        this.equipmentState = equipmentState;
    }

    public Long getWbsId() {
        return wbsId;
    }

    public void setWbsId(Long wbsId) {
        this.wbsId = wbsId;
    }

    public String getWbsCode() {
        return wbsCode;
    }

    public void setWbsCode(String wbsCode) {
        this.wbsCode = wbsCode;
    }

    public String getWbsName() {
        return wbsName;
    }

    public void setWbsName(String wbsName) {
        this.wbsName = wbsName;
    }

    public Long getSubjectId() {
        return subjectId;
    }

    public void setSubjectId(Long subjectId) {
        this.subjectId = subjectId;
    }

    public String getSubjectCode() {
        return subjectCode;
    }

    public void setSubjectCode(String subjectCode) {
        this.subjectCode = subjectCode;
    }

    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }

    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }

    public String getSourceName() {
        return sourceName;
    }

    public void setSourceName(String sourceName) {
        this.sourceName = sourceName;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public String getSourceCode() {
        return sourceCode;
    }

    public void setSourceCode(String sourceCode) {
        this.sourceCode = sourceCode;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getQuantitiesFactoryCode() {
        return quantitiesFactoryCode;
    }

    public void setQuantitiesFactoryCode(String quantitiesFactoryCode) {
        this.quantitiesFactoryCode = quantitiesFactoryCode;
    }
    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public Integer getQuantitiesNum() {
        return quantitiesNum;
    }

    public void setQuantitiesNum(Integer quantitiesNum) {
        this.quantitiesNum = quantitiesNum;
    }
    public BigDecimal getQuantitiesPrice() {
        return quantitiesPrice;
    }

    public void setQuantitiesPrice(BigDecimal quantitiesPrice) {
        this.quantitiesPrice = quantitiesPrice;
    }
    public Integer getRentNum() {
        return rentNum;
    }

    public void setRentNum(Integer rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public Date getPlanIntoDate() {
        return planIntoDate;
    }

    public void setPlanIntoDate(Date planIntoDate) {
        this.planIntoDate = planIntoDate;
    }
    public Date getPlanOutDate() {
        return planOutDate;
    }

    public void setPlanOutDate(Date planOutDate) {
        this.planOutDate = planOutDate;
    }
    public String getProductionManufactor() {
        return productionManufactor;
    }

    public void setProductionManufactor(String productionManufactor) {
        this.productionManufactor = productionManufactor;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getRentalId() {
        return rentalId;
    }

    public void setRentalId(Long rentalId) {
        this.rentalId = rentalId;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public BigDecimal getNotTaxQuantitiesPrice() {
        return notTaxQuantitiesPrice;
    }

    public void setNotTaxQuantitiesPrice(BigDecimal notTaxQuantitiesPrice) {
        this.notTaxQuantitiesPrice = notTaxQuantitiesPrice;
    }
    public BigDecimal getNotTaxQuantitiesMny() {
        return notTaxQuantitiesMny;
    }

    public void setNotTaxQuantitiesMny(BigDecimal notTaxQuantitiesMny) {
        this.notTaxQuantitiesMny = notTaxQuantitiesMny;
    }
    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }
    public Long getBillingUnitId() {
        return billingUnitId;
    }

    public void setBillingUnitId(Long billingUnitId) {
        this.billingUnitId = billingUnitId;
    }
    public String getBillingUnitName() {
        return billingUnitName;
    }

    public void setBillingUnitName(String billingUnitName) {
        this.billingUnitName = billingUnitName;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public BigDecimal getRentQuantitiesMny() {
        return rentQuantitiesMny;
    }

    public void setRentQuantitiesMny(BigDecimal rentQuantitiesMny) {
        this.rentQuantitiesMny = rentQuantitiesMny;
    }
    public BigDecimal getRentQuantitiesTaxMny() {
        return rentQuantitiesTaxMny;
    }

    public void setRentQuantitiesTaxMny(BigDecimal rentQuantitiesTaxMny) {
        this.rentQuantitiesTaxMny = rentQuantitiesTaxMny;
    }
    public BigDecimal getRentQuantitiesTax() {
        return rentQuantitiesTax;
    }

    public void setRentQuantitiesTax(BigDecimal rentQuantitiesTax) {
        this.rentQuantitiesTax = rentQuantitiesTax;
    }
    public Date getChargingStartDate() {
        return chargingStartDate;
    }

    public void setChargingStartDate(Date chargingStartDate) {
        this.chargingStartDate = chargingStartDate;
    }
    public Date getChargingEndDate() {
        return chargingEndDate;
    }

    public void setChargingEndDate(Date chargingEndDate) {
        this.chargingEndDate = chargingEndDate;
    }
    
}

==> ejc-proequipmentcorp-impl-3.0.0-20251013.062057-516-sources.jar: com/ejianc/business/proequipmentcorprent/rent/bean/RentRentalQuantitiesEntity.java <==
package com.ejianc.business.proequipmentcorprent.rent.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 租金计算工程量租明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_rent_rental_quantities")
public class RentRentalQuantitiesEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="quuipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="quantities_factory_code")
    private String quantitiesFactoryCode; // 设备出厂编号
    @TableField(value="category_id")
    private Long categoryId; // 设备类别id
    @TableField(value="category_name")
    private String categoryName; // 设备类别名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_name")
    private String unitName; // 单位
    @TableField(value="quantities_num")
    private BigDecimal quantitiesNum; // 工程数量
    @TableField(value="quantities_price")
    private BigDecimal quantitiesPrice; // 工程量单价
    @TableField(value="rent_num")
    private Integer rentNum; // 租赁数量
    @TableField(value="tax")
    private BigDecimal tax; // 税率
    @TableField(value="plan_into_date")
    private Date planIntoDate; // 计划进程日期
    @TableField(value="plan_out_date")
    private Date planOutDate; // 计划出场日期
    @TableField(value="production_manufactor")
    private String productionManufactor; // 生产厂家
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="rental_id")
    private Long rentalId; // 主表id
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编号
    @TableField(value="equipment_id")
    private Long equipmentId; // 设备id
    @TableField(value="not_tax_quantities_price")
    private BigDecimal notTaxQuantitiesPrice; // 
    @TableField(value="not_tax_quantities_mny")
    private BigDecimal notTaxQuantitiesMny; // 无税工程量金额
    @TableField(value="change_bid")
    private Long changeBid; // 变更子表id
    @TableField(value="billing_unit_id")
    private Long billingUnitId; // 计费单位
    @TableField(value="billing_unit_name")
    private String billingUnitName; // 计费单位名称
    @TableField(value="source_id")
    private Long sourceId; // 来源id
    @TableField(value="rent_quantities_mny")
    private BigDecimal rentQuantitiesMny; // 租赁金额(无税)
    @TableField(value="rent_quantities_tax_mny")
    private BigDecimal rentQuantitiesTaxMny; // 租赁金额
    @TableField(value="rent_quantities_tax")
    private BigDecimal rentQuantitiesTax; // 租赁税额
    @TableField(value="charging_start_date")
    private Date chargingStartDate; // 计费开始日期
    @TableField(value="charging_end_date")
    private Date chargingEndDate; // 计费结束日期
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源明细主键ID
    @TableField(value="source_name")
    private String sourceName; // 来源类型名称(记录—100231)
    @TableField(value="source_type")
    private Integer sourceType; // 来源类型
    @TableField(value="source_code")
    private String sourceCode; // 来源编码

    @TableField(value="wbs_id")
    private Long wbsId; // 核算对象主键
    @TableField(value="wbs_code")
    private String wbsCode; // 核算对象编码
    @TableField(value="wbs_name")
    private String wbsName; // 核算对象名称
    @TableField(value="subject_id")
    private Long subjectId; // 成本科目主键
    @TableField(value="subject_code")
    private String subjectCode; // 成本科目编码
    @TableField(value="subject_name")
    private String subjectName; // 成本科目名称

    @TableField(value="equipment_state")
    private Integer equipmentState;

    public Integer getEquipmentState() {
        return equipmentState;
    }

    public void setEquipmentState(Integer equipmentState) {
        this.equipmentState = equipmentState;
    }

    public Long getWbsId() {
        return wbsId;
    }

    public void setWbsId(Long wbsId) {
        this.wbsId = wbsId;
    }

    public String getWbsCode() {
        return wbsCode;
    }

    public void setWbsCode(String wbsCode) {
        this.wbsCode = wbsCode;
    }

    public String getWbsName() {
        return wbsName;
    }

    public void setWbsName(String wbsName) {
        this.wbsName = wbsName;
    }

    public Long getSubjectId() {
        return subjectId;
    }

    public void setSubjectId(Long subjectId) {
        this.subjectId = subjectId;
    }

    public String getSubjectCode() {
        return subjectCode;
    }

    public void setSubjectCode(String subjectCode) {
        this.subjectCode = subjectCode;
    }

    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }

    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }

    public String getSourceName() {
        return sourceName;
    }

    public void setSourceName(String sourceName) {
        this.sourceName = sourceName;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public String getSourceCode() {
        return sourceCode;
    }

    public void setSourceCode(String sourceCode) {
        this.sourceCode = sourceCode;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getQuantitiesFactoryCode() {
        return quantitiesFactoryCode;
    }

    public void setQuantitiesFactoryCode(String quantitiesFactoryCode) {
        this.quantitiesFactoryCode = quantitiesFactoryCode;
    }
    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getQuantitiesNum() {
        return quantitiesNum;
    }

    public void setQuantitiesNum(BigDecimal quantitiesNum) {
        this.quantitiesNum = quantitiesNum;
    }
    public BigDecimal getQuantitiesPrice() {
        return quantitiesPrice;
    }

    public void setQuantitiesPrice(BigDecimal quantitiesPrice) {
        this.quantitiesPrice = quantitiesPrice;
    }
    public Integer getRentNum() {
        return rentNum;
    }

    public void setRentNum(Integer rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public Date getPlanIntoDate() {
        return planIntoDate;
    }

    public void setPlanIntoDate(Date planIntoDate) {
        this.planIntoDate = planIntoDate;
    }
    public Date getPlanOutDate() {
        return planOutDate;
    }

    public void setPlanOutDate(Date planOutDate) {
        this.planOutDate = planOutDate;
    }
    public String getProductionManufactor() {
        return productionManufactor;
    }

    public void setProductionManufactor(String productionManufactor) {
        this.productionManufactor = productionManufactor;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getRentalId() {
        return rentalId;
    }

    public void setRentalId(Long rentalId) {
        this.rentalId = rentalId;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public BigDecimal getNotTaxQuantitiesPrice() {
        return notTaxQuantitiesPrice;
    }

    public void setNotTaxQuantitiesPrice(BigDecimal notTaxQuantitiesPrice) {
        this.notTaxQuantitiesPrice = notTaxQuantitiesPrice;
    }
    public BigDecimal getNotTaxQuantitiesMny() {
        return notTaxQuantitiesMny;
    }

    public void setNotTaxQuantitiesMny(BigDecimal notTaxQuantitiesMny) {
        this.notTaxQuantitiesMny = notTaxQuantitiesMny;
    }
    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }
    public Long getBillingUnitId() {
        return billingUnitId;
    }

    public void setBillingUnitId(Long billingUnitId) {
        this.billingUnitId = billingUnitId;
    }
    public String getBillingUnitName() {
        return billingUnitName;
    }

    public void setBillingUnitName(String billingUnitName) {
        this.billingUnitName = billingUnitName;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public BigDecimal getRentQuantitiesMny() {
        return rentQuantitiesMny;
    }

    public void setRentQuantitiesMny(BigDecimal rentQuantitiesMny) {
        this.rentQuantitiesMny = rentQuantitiesMny;
    }
    public BigDecimal getRentQuantitiesTaxMny() {
        return rentQuantitiesTaxMny;
    }

    public void setRentQuantitiesTaxMny(BigDecimal rentQuantitiesTaxMny) {
        this.rentQuantitiesTaxMny = rentQuantitiesTaxMny;
    }
    public BigDecimal getRentQuantitiesTax() {
        return rentQuantitiesTax;
    }

    public void setRentQuantitiesTax(BigDecimal rentQuantitiesTax) {
        this.rentQuantitiesTax = rentQuantitiesTax;
    }
    public Date getChargingStartDate() {
        return chargingStartDate;
    }

    public void setChargingStartDate(Date chargingStartDate) {
        this.chargingStartDate = chargingStartDate;
    }
    public Date getChargingEndDate() {
        return chargingEndDate;
    }

    public void setChargingEndDate(Date chargingEndDate) {
        this.chargingEndDate = chargingEndDate;
    }
    
}
